@@ -44,7 +44,8 @@ class Networkdev():
         self.dhcp6 = False
         self.search_domains = []
         self.nameservers = []
-        self.gateway = None
+        self.gateway4 = None
+        self.gateway6 = None
         self.essid = None
         self.wpa_psk = None
 
@@ -112,6 +113,11 @@ class Networkdev():
                    }
                  }
 
+        if self.gateway4:
+            result[self.ifname]['gateway4'] = self.gateway4
+        if self.gateway6:
+            result[self.ifname]['gateway6'] = self.gateway6
+
         if self.dhcp4:
             result[self.ifname]['dhcp4'] = True
         if self.dhcp6:
@@ -130,6 +136,11 @@ class Networkdev():
             if self.wpa_psk is not None:
                 ap['password'] = self.wpa_psk
 
+        if any(self.nameservers):
+            result[self.ifname]['nameservers'] = {}
+            result[self.ifname]['nameservers']['addresses'] = self.nameservers
+            result[self.ifname]['nameservers']['search'] = self.search_domains
+
         return result
 
     @property
@@ -241,11 +252,17 @@ class Networkdev():
         self.dhcp4 = False
         self.ipv4_addresses.clear()
         self.dhcp4_addresses.clear()
+        self.gateway4 = None
+
+    def remove_nameservers(self):
+        self.nameservers = []
+        self.search_domains = []
 
     def remove_ipv6_networks(self):
         self.dhcp6 = False
         self.ipv6_addresses.clear()
         self.dhcp6_addresses.clear()
+        self.gateway6 = None
 
     def add_network(self, family, network):
         # result = {
@@ -259,11 +276,12 @@ class Networkdev():
         address += '/' + network['network'].split('/')[1]
         if family == netifaces.AF_INET:
             self.ipv4_addresses.append(address)
+            self.gateway4 = network['gateway']
         elif family == netifaces.AF_INET6:
             self.ipv6_addresses.append(address)
-        self.gateway = network['gateway']
-        self.nameservers.append(network['nameserver'])
-        self.search_domains.append(network['searchdomains'])
+            self.gateway6 = network['gateway']
+        self.nameservers.extend(network['nameservers'])
+        self.search_domains.extend(network['searchdomains'])
 
 
 def valid_ipv4_address(addr):
@@ -288,41 +306,12 @@ def valid_ipv4_network(subnet):
 class NetworkModel(BaseModel):
     """ Model representing network interfaces
     """
-    base_signal = 'menu:network:main'
-    signals = [
-        ('Network main view',
-         base_signal,
-         'network'),
-        ('Network main view',
-         base_signal + ':start',
-         'start'),
-        ('Network finish',
-         'network:finish',
-         'network_finish'),
-        ('Network configure interface',
-         base_signal + ':configure-interface',
-         'network_configure_interface'),
-        ('Network configure ipv4 interface',
-         base_signal + ':configure-ipv4-interface',
-         'network_configure_ipv4_interface'),
-        ('Network configure wlan interface',
-         base_signal + ':configure-wlan-interface',
-         'network_configure_wlan_interface'),
-    ]
 
     additional_options = [
-        ('Set a custom IPv4 default route',
-         base_signal + ':set-default-v4-route',
-         'set_default_v4_route'),
-        ('Set a custom IPv6 default route',
-         base_signal + ':set-default-v6-route',
-         'set_default_v6_route'),
-        #('Bond interfaces',
-        # base_signal + ':bond-interfaces',
-        # 'bond_interfaces'),
-        # ('Install network driver',
-        #  'network:install-network-driver',
-        #  'install_network_driver')
+        ('Set a custom IPv4 default route', 'menu:network:main:set-default-v4-route'),
+        ('Set a custom IPv6 default route', 'menu:network:main:set-default-v6-route'),
+        #('Bond interfaces',                 'menu:network:main:bond-interfaces'),
+        #('Install network driver',          'network:install-network-driver'),
     ]
 
     # TODO: what is "linear" level?
@@ -351,14 +340,6 @@ class NetworkModel(BaseModel):
         self.v6_gateway_dev = None
         self.network_routes = {}
 
-    def get_signal_by_name(self, selection):
-        for x, y, z in self.get_signals():
-            if x == selection:
-                return y
-
-    def get_signals(self):
-        return self.signals + self.additional_options
-
     def get_menu(self):
         return self.additional_options
 
